nova_ec
  • Home
  • API Reference
  • Tutorial
  • Getting Started
  • Configuration
  1. API Reference
  2. Geocoding Module
  3. geocoder
  • Overview
    • Overview
  • Getting Started
    • Installation and Setup
    • Configuration
  • Tutorial
    • Project Setup Tutorial
  • API Reference
    • Function reference
    • Config Module
      • config_manager
    • Data Module
      • system_data
      • energy_community
    • Geocoding Module
      • geocoder
    • Matching Module
      • ec_matcher
      • county_matcher
      • eligibility
      • export_utils
    • Retrieval Module
      • data_retriever
    • Utils Module
      • logger
      • analysis_utils
    • Main Module
      • main
      • cli

On this page

  • geocoder
    • Functions
      • apply_mappings
      • create_summary_report
      • get_most_recent_file
      • load_config
      • load_existing_responses
      • log_dataframe_summary
      • main
      • resolve_path_variables
      • save_responses
      • standardize_address

Other Formats

  • Github (GFM)
  1. API Reference
  2. Geocoding Module
  3. geocoder

geocoder

geocoding.geocoder

Module for geocoding solar system addresses.

Functions

Name Description
apply_mappings Apply a dictionary of string replacements to an address.
create_summary_report Create a summary report with rich tables.
get_most_recent_file Get the most recent file matching the given glob pattern based on filename date.
load_config Load configuration from YAML file and resolve path variables.
load_existing_responses Load existing geocoding responses with error handling.
log_dataframe_summary Log a summary of the dataframe contents using rich tables.
main Main execution function with enhanced error handling.
resolve_path_variables Resolve variables in path strings like {variable} with their values.
save_responses Save geocoding responses to JSON file.
standardize_address Standardize address format with proper error handling.

apply_mappings

geocoding.geocoder.apply_mappings(addr, mappings)

Apply a dictionary of string replacements to an address.

create_summary_report

geocoding.geocoder.create_summary_report(
    input_df,
    output_df,
    not_geocoded_systems,
    geocoded_new,
)

Create a summary report with rich tables.

get_most_recent_file

geocoding.geocoder.get_most_recent_file(pattern)

Get the most recent file matching the given glob pattern based on filename date.

load_config

geocoding.geocoder.load_config(config_path='config.yaml')

Load configuration from YAML file and resolve path variables.

load_existing_responses

geocoding.geocoder.load_existing_responses(json_path)

Load existing geocoding responses with error handling.

log_dataframe_summary

geocoding.geocoder.log_dataframe_summary(df, name)

Log a summary of the dataframe contents using rich tables.

main

geocoding.geocoder.main()

Main execution function with enhanced error handling.

resolve_path_variables

geocoding.geocoder.resolve_path_variables(config)

Resolve variables in path strings like {variable} with their values.

save_responses

geocoding.geocoder.save_responses(responses, json_path)

Save geocoding responses to JSON file.

standardize_address

geocoding.geocoder.standardize_address(address)

Standardize address format with proper error handling. Returns None if address cannot be standardized.

energy_community
ec_matcher
 
 
  • Built with [Quarto](https://quarto.org/) and [quartodoc](https://machow.github.io/quartodoc/)