nova_ec
  • Home
  • API Reference
  • Tutorial
  • Getting Started
  • Configuration
  1. API Reference
  2. Utils Module
  3. logger
  • Overview
    • Overview
  • Getting Started
    • Installation and Setup
    • Configuration
  • Tutorial
    • Project Setup Tutorial
  • API Reference
    • Function reference
    • Config Module
      • config_manager
    • Data Module
      • system_data
      • energy_community
    • Geocoding Module
      • geocoder
    • Matching Module
      • ec_matcher
      • county_matcher
      • eligibility
      • export_utils
    • Retrieval Module
      • data_retriever
    • Utils Module
      • logger
      • analysis_utils
    • Main Module
      • main
      • cli

On this page

  • logger
    • Functions
      • setup_logger

Other Formats

  • Github (GFM)
  1. API Reference
  2. Utils Module
  3. logger

logger

utils.logger

Logging utilities for Nova EC.

Functions

Name Description
setup_logger Set up logging configuration with file and console outputs.

setup_logger

utils.logger.setup_logger(log_path=None)

Set up logging configuration with file and console outputs.

Args: log_path: Optional path to save the log file

Returns: Tuple of (logger, console)

data_retriever
analysis_utils
 
 
  • Built with [Quarto](https://quarto.org/) and [quartodoc](https://machow.github.io/quartodoc/)